@@ -6,6 +6,12 @@ from longerusernameandemail.forms import UserCreationForm, UserChangeForm
 
 
 class LongerUsernameAndEmailUserAdmin(UserAdmin):
+    add_fieldsets = (
+        (None, {
+            'classes': ('wide',),
+            'fields': ('username', 'email', 'password1', 'password2')}
+        ),
+    )
     add_form = UserCreationForm
     form = UserChangeForm
 
